@@ -77,6 +77,8 @@ signature_offset (GICallableInfo *info)
     case GI_INFO_TYPE_SIGNAL:
       sigoff = G_STRUCT_OFFSET (SignalBlob, signature);
       break;
+    default:
+      g_assert_not_reached ();
     }
   if (sigoff >= 0)
     return *(guint32 *)&rinfo->typelib->data[rinfo->offset + sigoff];
@@ -535,7 +537,7 @@ gi_type_info_extract_ffi_return_value (GITypeInfo                  *return_info,
                 arg->v_int32 = (gint32) ffi_value->v_long;
                 break;
             default:
-                arg->v_pointer = (gpointer) ffi_value->v_ulong;
+                arg->v_pointer = (gpointer) ffi_value->v_pointer;
                 break;
             }
 
@@ -543,7 +545,7 @@ gi_type_info_extract_ffi_return_value (GITypeInfo                  *return_info,
         }
         break;
     default:
-        arg->v_pointer = (gpointer) ffi_value->v_ulong;
+        arg->v_pointer = (gpointer) ffi_value->v_pointer;
         break;
     }
 }
